IsContiguous

Trait IsContiguous 

pub unsafe trait IsContiguous { }
Marker trait indicating that a storage is stored contiguously in memory.

Safety

The storage requirement means that for any value of i in [0, nrows * ncols - 1], the value .get_unchecked_linear returns one of the matrix component. This trait is unsafe because failing to comply to this may cause Undefined Behaviors.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T, R, C> IsContiguous for VecStorage<T, R, C>
where R: Dim, C: Dim,

Source

impl<T, R, C> IsContiguous for ViewStorage<'_, T, R, C, Const<1>, R>
where R: DimName, C: Dim + IsNotStaticOne,

Source

impl<T, R, C> IsContiguous for ViewStorageMut<'_, T, R, C, Const<1>, R>
where R: DimName, C: Dim + IsNotStaticOne,

Source

impl<T, R, CStride> IsContiguous for ViewStorage<'_, T, R, Const<1>, Const<1>, CStride>
where R: Dim, CStride: Dim,

Source

impl<T, R, CStride> IsContiguous for ViewStorageMut<'_, T, R, Const<1>, Const<1>, CStride>
where R: Dim, CStride: Dim,

Source

impl<T, const R: usize, const C: usize> IsContiguous for ArrayStorage<T, R, C>