pub unsafe trait IsContiguous { }Expand description
Marker trait indicating that a storage is stored contiguously in memory.
Safety
The storage requirement means that for any value of i in [0, nrows * ncols - 1], the value
.get_unchecked_linear returns one of the matrix component. This trait is unsafe because
failing to comply to this may cause Undefined Behaviors.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".